# Generated from /Users/macbookpro/Desktop/antlr/wxclDefinition/wxcl.g4 by ANTLR 4.13.2
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,64,407,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,7,
        6,2,7,7,7,2,8,7,8,2,9,7,9,2,10,7,10,2,11,7,11,2,12,7,12,2,13,7,13,
        2,14,7,14,2,15,7,15,2,16,7,16,2,17,7,17,2,18,7,18,2,19,7,19,2,20,
        7,20,2,21,7,21,2,22,7,22,2,23,7,23,2,24,7,24,2,25,7,25,2,26,7,26,
        2,27,7,27,2,28,7,28,2,29,7,29,2,30,7,30,2,31,7,31,2,32,7,32,2,33,
        7,33,2,34,7,34,2,35,7,35,2,36,7,36,2,37,7,37,2,38,7,38,2,39,7,39,
        2,40,7,40,2,41,7,41,2,42,7,42,2,43,7,43,2,44,7,44,2,45,7,45,1,0,
        1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
        1,2,5,2,111,8,2,10,2,12,2,114,9,2,1,3,4,3,117,8,3,11,3,12,3,118,
        1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,5,5,5,132,8,5,10,5,12,
        5,135,9,5,1,6,5,6,138,8,6,10,6,12,6,141,9,6,1,7,1,7,1,7,1,7,1,7,
        1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,3,8,160,8,8,1,8,
        1,8,1,8,3,8,165,8,8,3,8,167,8,8,1,8,1,8,1,9,1,9,1,9,3,9,174,8,9,
        1,9,1,9,1,10,1,10,1,10,5,10,181,8,10,10,10,12,10,184,9,10,1,11,1,
        11,1,11,1,11,1,12,1,12,1,12,1,12,1,13,1,13,1,13,1,13,1,13,1,13,1,
        13,1,14,1,14,1,14,1,14,1,14,3,14,206,8,14,1,15,1,15,1,15,1,15,1,
        15,1,16,1,16,1,16,1,16,1,16,1,16,1,16,1,16,1,17,1,17,1,17,1,17,3,
        17,225,8,17,1,17,1,17,1,17,1,17,1,18,1,18,1,18,1,18,1,18,1,18,1,
        18,5,18,238,8,18,10,18,12,18,241,9,18,1,18,1,18,1,19,1,19,3,19,247,
        8,19,1,20,1,20,1,20,1,20,1,20,1,20,1,20,5,20,256,8,20,10,20,12,20,
        259,9,20,1,20,1,20,1,21,1,21,3,21,265,8,21,1,22,1,22,1,22,1,22,1,
        22,1,22,3,22,273,8,22,1,22,1,22,1,22,1,23,1,23,1,24,1,24,1,24,1,
        24,1,24,1,25,1,25,1,25,1,25,1,25,1,25,1,25,1,25,1,26,1,26,1,26,1,
        26,5,26,297,8,26,10,26,12,26,300,9,26,1,26,1,26,1,27,1,27,1,27,1,
        27,1,27,1,27,1,27,1,27,1,27,1,27,1,27,1,27,1,27,1,27,3,27,318,8,
        27,1,28,1,28,1,28,1,28,1,29,1,29,1,29,1,29,1,30,1,30,1,30,1,30,1,
        31,1,31,1,31,1,31,1,31,1,31,1,31,1,31,1,31,1,32,1,32,3,32,343,8,
        32,1,33,1,33,1,34,1,34,1,34,1,34,1,35,1,35,1,35,1,35,1,35,1,35,1,
        35,1,35,1,35,1,36,1,36,1,37,1,37,1,37,1,37,1,37,1,37,1,38,1,38,1,
        38,1,38,1,38,3,38,373,8,38,1,38,1,38,1,39,1,39,1,39,1,39,1,39,1,
        39,1,39,1,40,1,40,1,40,1,40,1,41,1,41,1,41,1,42,1,42,1,42,1,42,1,
        43,1,43,1,43,1,43,1,44,1,44,1,44,1,44,1,45,1,45,1,45,1,45,1,45,0,
        0,46,0,2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,
        44,46,48,50,52,54,56,58,60,62,64,66,68,70,72,74,76,78,80,82,84,86,
        88,90,0,2,2,0,14,14,29,29,2,0,40,40,56,56,403,0,92,1,0,0,0,2,100,
        1,0,0,0,4,112,1,0,0,0,6,116,1,0,0,0,8,120,1,0,0,0,10,133,1,0,0,0,
        12,139,1,0,0,0,14,142,1,0,0,0,16,159,1,0,0,0,18,170,1,0,0,0,20,177,
        1,0,0,0,22,185,1,0,0,0,24,189,1,0,0,0,26,193,1,0,0,0,28,205,1,0,
        0,0,30,207,1,0,0,0,32,212,1,0,0,0,34,220,1,0,0,0,36,230,1,0,0,0,
        38,244,1,0,0,0,40,248,1,0,0,0,42,262,1,0,0,0,44,266,1,0,0,0,46,277,
        1,0,0,0,48,279,1,0,0,0,50,284,1,0,0,0,52,292,1,0,0,0,54,317,1,0,
        0,0,56,319,1,0,0,0,58,323,1,0,0,0,60,327,1,0,0,0,62,331,1,0,0,0,
        64,342,1,0,0,0,66,344,1,0,0,0,68,346,1,0,0,0,70,350,1,0,0,0,72,359,
        1,0,0,0,74,361,1,0,0,0,76,367,1,0,0,0,78,376,1,0,0,0,80,383,1,0,
        0,0,82,387,1,0,0,0,84,390,1,0,0,0,86,394,1,0,0,0,88,398,1,0,0,0,
        90,402,1,0,0,0,92,93,5,1,0,0,93,94,5,2,0,0,94,95,5,61,0,0,95,96,
        5,3,0,0,96,97,3,2,1,0,97,98,3,4,2,0,98,99,3,6,3,0,99,1,1,0,0,0,100,
        101,5,4,0,0,101,102,5,5,0,0,102,103,5,56,0,0,103,104,5,6,0,0,104,
        105,5,61,0,0,105,106,5,6,0,0,106,107,5,57,0,0,107,108,5,7,0,0,108,
        3,1,0,0,0,109,111,3,14,7,0,110,109,1,0,0,0,111,114,1,0,0,0,112,110,
        1,0,0,0,112,113,1,0,0,0,113,5,1,0,0,0,114,112,1,0,0,0,115,117,3,
        8,4,0,116,115,1,0,0,0,117,118,1,0,0,0,118,116,1,0,0,0,118,119,1,
        0,0,0,119,7,1,0,0,0,120,121,5,8,0,0,121,122,5,9,0,0,122,123,5,60,
        0,0,123,124,5,2,0,0,124,125,5,61,0,0,125,126,5,5,0,0,126,127,3,10,
        5,0,127,128,5,7,0,0,128,129,3,12,6,0,129,9,1,0,0,0,130,132,3,16,
        8,0,131,130,1,0,0,0,132,135,1,0,0,0,133,131,1,0,0,0,133,134,1,0,
        0,0,134,11,1,0,0,0,135,133,1,0,0,0,136,138,3,14,7,0,137,136,1,0,
        0,0,138,141,1,0,0,0,139,137,1,0,0,0,139,140,1,0,0,0,140,13,1,0,0,
        0,141,139,1,0,0,0,142,143,5,63,0,0,143,144,5,2,0,0,144,145,3,52,
        26,0,145,146,5,3,0,0,146,15,1,0,0,0,147,160,3,18,9,0,148,160,3,22,
        11,0,149,160,3,24,12,0,150,160,3,26,13,0,151,160,3,30,15,0,152,160,
        3,32,16,0,153,160,3,34,17,0,154,160,3,36,18,0,155,160,3,40,20,0,
        156,160,3,44,22,0,157,160,3,48,24,0,158,160,3,50,25,0,159,147,1,
        0,0,0,159,148,1,0,0,0,159,149,1,0,0,0,159,150,1,0,0,0,159,151,1,
        0,0,0,159,152,1,0,0,0,159,153,1,0,0,0,159,154,1,0,0,0,159,155,1,
        0,0,0,159,156,1,0,0,0,159,157,1,0,0,0,159,158,1,0,0,0,160,166,1,
        0,0,0,161,164,5,10,0,0,162,165,3,52,26,0,163,165,5,63,0,0,164,162,
        1,0,0,0,164,163,1,0,0,0,165,167,1,0,0,0,166,161,1,0,0,0,166,167,
        1,0,0,0,167,168,1,0,0,0,168,169,5,3,0,0,169,17,1,0,0,0,170,171,5,
        11,0,0,171,173,5,12,0,0,172,174,3,20,10,0,173,172,1,0,0,0,173,174,
        1,0,0,0,174,175,1,0,0,0,175,176,5,13,0,0,176,19,1,0,0,0,177,182,
        5,61,0,0,178,179,5,6,0,0,179,181,5,61,0,0,180,178,1,0,0,0,181,184,
        1,0,0,0,182,180,1,0,0,0,182,183,1,0,0,0,183,21,1,0,0,0,184,182,1,
        0,0,0,185,186,5,14,0,0,186,187,5,9,0,0,187,188,5,61,0,0,188,23,1,
        0,0,0,189,190,5,15,0,0,190,191,5,9,0,0,191,192,5,61,0,0,192,25,1,
        0,0,0,193,194,5,16,0,0,194,195,5,17,0,0,195,196,3,28,14,0,196,197,
        5,18,0,0,197,198,5,9,0,0,198,199,5,61,0,0,199,27,1,0,0,0,200,201,
        5,19,0,0,201,202,5,9,0,0,202,206,5,63,0,0,203,206,5,20,0,0,204,206,
        5,21,0,0,205,200,1,0,0,0,205,203,1,0,0,0,205,204,1,0,0,0,206,29,
        1,0,0,0,207,208,5,22,0,0,208,209,5,12,0,0,209,210,3,10,5,0,210,211,
        5,13,0,0,211,31,1,0,0,0,212,213,5,23,0,0,213,214,5,17,0,0,214,215,
        5,61,0,0,215,216,5,18,0,0,216,217,5,12,0,0,217,218,3,10,5,0,218,
        219,5,13,0,0,219,33,1,0,0,0,220,224,5,24,0,0,221,222,5,17,0,0,222,
        223,5,61,0,0,223,225,5,18,0,0,224,221,1,0,0,0,224,225,1,0,0,0,225,
        226,1,0,0,0,226,227,5,12,0,0,227,228,3,10,5,0,228,229,5,13,0,0,229,
        35,1,0,0,0,230,231,5,25,0,0,231,232,5,2,0,0,232,233,5,61,0,0,233,
        234,5,12,0,0,234,239,3,38,19,0,235,236,5,6,0,0,236,238,3,38,19,0,
        237,235,1,0,0,0,238,241,1,0,0,0,239,237,1,0,0,0,239,240,1,0,0,0,
        240,242,1,0,0,0,241,239,1,0,0,0,242,243,5,13,0,0,243,37,1,0,0,0,
        244,246,5,61,0,0,245,247,5,26,0,0,246,245,1,0,0,0,246,247,1,0,0,
        0,247,39,1,0,0,0,248,249,5,27,0,0,249,250,5,2,0,0,250,251,5,61,0,
        0,251,252,5,12,0,0,252,257,3,42,21,0,253,254,5,6,0,0,254,256,3,42,
        21,0,255,253,1,0,0,0,256,259,1,0,0,0,257,255,1,0,0,0,257,258,1,0,
        0,0,258,260,1,0,0,0,259,257,1,0,0,0,260,261,5,13,0,0,261,41,1,0,
        0,0,262,264,5,61,0,0,263,265,5,26,0,0,264,263,1,0,0,0,264,265,1,
        0,0,0,265,43,1,0,0,0,266,267,5,28,0,0,267,268,5,17,0,0,268,269,3,
        46,23,0,269,272,5,18,0,0,270,271,5,9,0,0,271,273,5,61,0,0,272,270,
        1,0,0,0,272,273,1,0,0,0,273,274,1,0,0,0,274,275,5,2,0,0,275,276,
        5,61,0,0,276,45,1,0,0,0,277,278,7,0,0,0,278,47,1,0,0,0,279,280,5,
        30,0,0,280,281,5,12,0,0,281,282,3,10,5,0,282,283,5,13,0,0,283,49,
        1,0,0,0,284,285,5,31,0,0,285,286,5,17,0,0,286,287,5,63,0,0,287,288,
        5,18,0,0,288,289,5,12,0,0,289,290,3,10,5,0,290,291,5,13,0,0,291,
        51,1,0,0,0,292,293,5,32,0,0,293,298,3,54,27,0,294,295,5,6,0,0,295,
        297,3,54,27,0,296,294,1,0,0,0,297,300,1,0,0,0,298,296,1,0,0,0,298,
        299,1,0,0,0,299,301,1,0,0,0,300,298,1,0,0,0,301,302,5,32,0,0,302,
        53,1,0,0,0,303,318,3,56,28,0,304,318,3,58,29,0,305,318,3,60,30,0,
        306,318,3,62,31,0,307,318,3,68,34,0,308,318,3,70,35,0,309,318,3,
        74,37,0,310,318,3,76,38,0,311,318,3,78,39,0,312,318,3,80,40,0,313,
        318,3,84,42,0,314,318,3,86,43,0,315,318,3,88,44,0,316,318,3,90,45,
        0,317,303,1,0,0,0,317,304,1,0,0,0,317,305,1,0,0,0,317,306,1,0,0,
        0,317,307,1,0,0,0,317,308,1,0,0,0,317,309,1,0,0,0,317,310,1,0,0,
        0,317,311,1,0,0,0,317,312,1,0,0,0,317,313,1,0,0,0,317,314,1,0,0,
        0,317,315,1,0,0,0,317,316,1,0,0,0,318,55,1,0,0,0,319,320,5,33,0,
        0,320,321,5,2,0,0,321,322,5,56,0,0,322,57,1,0,0,0,323,324,5,34,0,
        0,324,325,5,2,0,0,325,326,3,82,41,0,326,59,1,0,0,0,327,328,5,35,
        0,0,328,329,5,2,0,0,329,330,3,82,41,0,330,61,1,0,0,0,331,332,5,36,
        0,0,332,333,5,37,0,0,333,334,3,64,32,0,334,335,5,6,0,0,335,336,5,
        52,0,0,336,337,5,6,0,0,337,338,3,66,33,0,338,339,5,38,0,0,339,63,
        1,0,0,0,340,343,3,82,41,0,341,343,5,39,0,0,342,340,1,0,0,0,342,341,
        1,0,0,0,343,65,1,0,0,0,344,345,7,1,0,0,345,67,1,0,0,0,346,347,5,
        41,0,0,347,348,5,2,0,0,348,349,5,53,0,0,349,69,1,0,0,0,350,351,5,
        42,0,0,351,352,5,37,0,0,352,353,5,55,0,0,353,354,5,6,0,0,354,355,
        3,72,36,0,355,356,5,6,0,0,356,357,5,61,0,0,357,358,5,38,0,0,358,
        71,1,0,0,0,359,360,3,82,41,0,360,73,1,0,0,0,361,362,5,43,0,0,362,
        363,5,2,0,0,363,364,5,53,0,0,364,365,5,9,0,0,365,366,5,54,0,0,366,
        75,1,0,0,0,367,368,5,44,0,0,368,369,5,37,0,0,369,372,5,56,0,0,370,
        371,5,6,0,0,371,373,5,61,0,0,372,370,1,0,0,0,372,373,1,0,0,0,373,
        374,1,0,0,0,374,375,5,38,0,0,375,77,1,0,0,0,376,377,5,45,0,0,377,
        378,5,37,0,0,378,379,3,82,41,0,379,380,5,6,0,0,380,381,3,82,41,0,
        381,382,5,38,0,0,382,79,1,0,0,0,383,384,5,46,0,0,384,385,5,2,0,0,
        385,386,3,82,41,0,386,81,1,0,0,0,387,388,5,60,0,0,388,389,5,59,0,
        0,389,83,1,0,0,0,390,391,5,47,0,0,391,392,5,2,0,0,392,393,3,82,41,
        0,393,85,1,0,0,0,394,395,5,48,0,0,395,396,5,2,0,0,396,397,5,60,0,
        0,397,87,1,0,0,0,398,399,5,49,0,0,399,400,5,2,0,0,400,401,3,82,41,
        0,401,89,1,0,0,0,402,403,5,50,0,0,403,404,5,2,0,0,404,405,5,60,0,
        0,405,91,1,0,0,0,20,112,118,133,139,159,164,166,173,182,205,224,
        239,246,257,264,272,298,317,342,372
    ]

class wxclParser ( Parser ):

    grammarFileName = "wxcl.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "'project'", "':'", "';'", "'navigationBar'", 
                     "'{'", "','", "'}'", "'page'", "'-'", "'=>'", "'swiper'", 
                     "'['", "']'", "'text'", "'image'", "'button'", "'<'", 
                     "'>'", "'navigation'", "'submit'", "'reset'", "'list'", 
                     "'form'", "'label'", "'radio-group'", "'*'", "'checkbox-group'", 
                     "'input'", "'password'", "'view'", "'navigator'", "'''", 
                     "'color'", "'width'", "'height'", "'border'", "'('", 
                     "')'", "'width-initial'", "'color-initial'", "'position'", 
                     "'font'", "'align'", "'background'", "'spacing'", "'border-radius'", 
                     "'padding'", "'listCol'", "'listColHeight'", "'interval'" ]

    symbolicNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "Theme", "BorderStyle", 
                      "HorizontalValue", "VerticalValue", "FontWeight", 
                      "ColorValue", "HexColor", "Boolean", "Unit", "Number", 
                      "String", "WS", "VariableName", "Comment" ]

    RULE_project = 0
    RULE_navigationBar = 1
    RULE_appStyleVariableList = 2
    RULE_pageList = 3
    RULE_page = 4
    RULE_pageContent = 5
    RULE_styleVariableList = 6
    RULE_styleVariable = 7
    RULE_component = 8
    RULE_swiper = 9
    RULE_ablum = 10
    RULE_text = 11
    RULE_image = 12
    RULE_button = 13
    RULE_function = 14
    RULE_list = 15
    RULE_form = 16
    RULE_label = 17
    RULE_radioGroup = 18
    RULE_radioOption = 19
    RULE_checkboxGroup = 20
    RULE_checkboxOption = 21
    RULE_input = 22
    RULE_inputType = 23
    RULE_view = 24
    RULE_navigator = 25
    RULE_gui = 26
    RULE_style = 27
    RULE_color = 28
    RULE_width = 29
    RULE_height = 30
    RULE_border = 31
    RULE_borderWidth = 32
    RULE_borderColor = 33
    RULE_position = 34
    RULE_font = 35
    RULE_fontSize = 36
    RULE_textAlign = 37
    RULE_background = 38
    RULE_spacing = 39
    RULE_borderRadius = 40
    RULE_rpxValue = 41
    RULE_padding = 42
    RULE_list_col = 43
    RULE_list_rowHeight = 44
    RULE_swiper_interval = 45

    ruleNames =  [ "project", "navigationBar", "appStyleVariableList", "pageList", 
                   "page", "pageContent", "styleVariableList", "styleVariable", 
                   "component", "swiper", "ablum", "text", "image", "button", 
                   "function", "list", "form", "label", "radioGroup", "radioOption", 
                   "checkboxGroup", "checkboxOption", "input", "inputType", 
                   "view", "navigator", "gui", "style", "color", "width", 
                   "height", "border", "borderWidth", "borderColor", "position", 
                   "font", "fontSize", "textAlign", "background", "spacing", 
                   "borderRadius", "rpxValue", "padding", "list_col", "list_rowHeight", 
                   "swiper_interval" ]

    EOF = Token.EOF
    T__0=1
    T__1=2
    T__2=3
    T__3=4
    T__4=5
    T__5=6
    T__6=7
    T__7=8
    T__8=9
    T__9=10
    T__10=11
    T__11=12
    T__12=13
    T__13=14
    T__14=15
    T__15=16
    T__16=17
    T__17=18
    T__18=19
    T__19=20
    T__20=21
    T__21=22
    T__22=23
    T__23=24
    T__24=25
    T__25=26
    T__26=27
    T__27=28
    T__28=29
    T__29=30
    T__30=31
    T__31=32
    T__32=33
    T__33=34
    T__34=35
    T__35=36
    T__36=37
    T__37=38
    T__38=39
    T__39=40
    T__40=41
    T__41=42
    T__42=43
    T__43=44
    T__44=45
    T__45=46
    T__46=47
    T__47=48
    T__48=49
    T__49=50
    Theme=51
    BorderStyle=52
    HorizontalValue=53
    VerticalValue=54
    FontWeight=55
    ColorValue=56
    HexColor=57
    Boolean=58
    Unit=59
    Number=60
    String=61
    WS=62
    VariableName=63
    Comment=64

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.13.2")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class ProjectContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def navigationBar(self):
            return self.getTypedRuleContext(wxclParser.NavigationBarContext,0)


        def appStyleVariableList(self):
            return self.getTypedRuleContext(wxclParser.AppStyleVariableListContext,0)


        def pageList(self):
            return self.getTypedRuleContext(wxclParser.PageListContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_project

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProject" ):
                listener.enterProject(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProject" ):
                listener.exitProject(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitProject" ):
                return visitor.visitProject(self)
            else:
                return visitor.visitChildren(self)




    def project(self):

        localctx = wxclParser.ProjectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_project)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 92
            self.match(wxclParser.T__0)
            self.state = 93
            self.match(wxclParser.T__1)
            self.state = 94
            self.match(wxclParser.String)
            self.state = 95
            self.match(wxclParser.T__2)
            self.state = 96
            self.navigationBar()
            self.state = 97
            self.appStyleVariableList()
            self.state = 98
            self.pageList()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NavigationBarContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ColorValue(self):
            return self.getToken(wxclParser.ColorValue, 0)

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def HexColor(self):
            return self.getToken(wxclParser.HexColor, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_navigationBar

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNavigationBar" ):
                listener.enterNavigationBar(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNavigationBar" ):
                listener.exitNavigationBar(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitNavigationBar" ):
                return visitor.visitNavigationBar(self)
            else:
                return visitor.visitChildren(self)




    def navigationBar(self):

        localctx = wxclParser.NavigationBarContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_navigationBar)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 100
            self.match(wxclParser.T__3)
            self.state = 101
            self.match(wxclParser.T__4)
            self.state = 102
            self.match(wxclParser.ColorValue)
            self.state = 103
            self.match(wxclParser.T__5)
            self.state = 104
            self.match(wxclParser.String)
            self.state = 105
            self.match(wxclParser.T__5)
            self.state = 106
            self.match(wxclParser.HexColor)
            self.state = 107
            self.match(wxclParser.T__6)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AppStyleVariableListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def styleVariable(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.StyleVariableContext)
            else:
                return self.getTypedRuleContext(wxclParser.StyleVariableContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_appStyleVariableList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAppStyleVariableList" ):
                listener.enterAppStyleVariableList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAppStyleVariableList" ):
                listener.exitAppStyleVariableList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAppStyleVariableList" ):
                return visitor.visitAppStyleVariableList(self)
            else:
                return visitor.visitChildren(self)




    def appStyleVariableList(self):

        localctx = wxclParser.AppStyleVariableListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_appStyleVariableList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 112
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==63:
                self.state = 109
                self.styleVariable()
                self.state = 114
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PageListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def page(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.PageContext)
            else:
                return self.getTypedRuleContext(wxclParser.PageContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_pageList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPageList" ):
                listener.enterPageList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPageList" ):
                listener.exitPageList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPageList" ):
                return visitor.visitPageList(self)
            else:
                return visitor.visitChildren(self)




    def pageList(self):

        localctx = wxclParser.PageListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_pageList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 116 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 115
                self.page()
                self.state = 118 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==8):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PageContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Number(self):
            return self.getToken(wxclParser.Number, 0)

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def pageContent(self):
            return self.getTypedRuleContext(wxclParser.PageContentContext,0)


        def styleVariableList(self):
            return self.getTypedRuleContext(wxclParser.StyleVariableListContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_page

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPage" ):
                listener.enterPage(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPage" ):
                listener.exitPage(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPage" ):
                return visitor.visitPage(self)
            else:
                return visitor.visitChildren(self)




    def page(self):

        localctx = wxclParser.PageContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_page)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 120
            self.match(wxclParser.T__7)
            self.state = 121
            self.match(wxclParser.T__8)
            self.state = 122
            self.match(wxclParser.Number)
            self.state = 123
            self.match(wxclParser.T__1)
            self.state = 124
            self.match(wxclParser.String)
            self.state = 125
            self.match(wxclParser.T__4)
            self.state = 126
            self.pageContent()
            self.state = 127
            self.match(wxclParser.T__6)
            self.state = 128
            self.styleVariableList()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PageContentContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def component(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.ComponentContext)
            else:
                return self.getTypedRuleContext(wxclParser.ComponentContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_pageContent

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPageContent" ):
                listener.enterPageContent(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPageContent" ):
                listener.exitPageContent(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPageContent" ):
                return visitor.visitPageContent(self)
            else:
                return visitor.visitChildren(self)




    def pageContent(self):

        localctx = wxclParser.PageContentContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_pageContent)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 133
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 3686909952) != 0):
                self.state = 130
                self.component()
                self.state = 135
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StyleVariableListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def styleVariable(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.StyleVariableContext)
            else:
                return self.getTypedRuleContext(wxclParser.StyleVariableContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_styleVariableList

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStyleVariableList" ):
                listener.enterStyleVariableList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStyleVariableList" ):
                listener.exitStyleVariableList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStyleVariableList" ):
                return visitor.visitStyleVariableList(self)
            else:
                return visitor.visitChildren(self)




    def styleVariableList(self):

        localctx = wxclParser.StyleVariableListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_styleVariableList)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 139
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==63:
                self.state = 136
                self.styleVariable()
                self.state = 141
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StyleVariableContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def VariableName(self):
            return self.getToken(wxclParser.VariableName, 0)

        def gui(self):
            return self.getTypedRuleContext(wxclParser.GuiContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_styleVariable

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStyleVariable" ):
                listener.enterStyleVariable(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStyleVariable" ):
                listener.exitStyleVariable(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStyleVariable" ):
                return visitor.visitStyleVariable(self)
            else:
                return visitor.visitChildren(self)




    def styleVariable(self):

        localctx = wxclParser.StyleVariableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_styleVariable)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 142
            self.match(wxclParser.VariableName)
            self.state = 143
            self.match(wxclParser.T__1)
            self.state = 144
            self.gui()
            self.state = 145
            self.match(wxclParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ComponentContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def swiper(self):
            return self.getTypedRuleContext(wxclParser.SwiperContext,0)


        def text(self):
            return self.getTypedRuleContext(wxclParser.TextContext,0)


        def image(self):
            return self.getTypedRuleContext(wxclParser.ImageContext,0)


        def button(self):
            return self.getTypedRuleContext(wxclParser.ButtonContext,0)


        def list_(self):
            return self.getTypedRuleContext(wxclParser.ListContext,0)


        def form(self):
            return self.getTypedRuleContext(wxclParser.FormContext,0)


        def label(self):
            return self.getTypedRuleContext(wxclParser.LabelContext,0)


        def radioGroup(self):
            return self.getTypedRuleContext(wxclParser.RadioGroupContext,0)


        def checkboxGroup(self):
            return self.getTypedRuleContext(wxclParser.CheckboxGroupContext,0)


        def input_(self):
            return self.getTypedRuleContext(wxclParser.InputContext,0)


        def view(self):
            return self.getTypedRuleContext(wxclParser.ViewContext,0)


        def navigator(self):
            return self.getTypedRuleContext(wxclParser.NavigatorContext,0)


        def gui(self):
            return self.getTypedRuleContext(wxclParser.GuiContext,0)


        def VariableName(self):
            return self.getToken(wxclParser.VariableName, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_component

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterComponent" ):
                listener.enterComponent(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitComponent" ):
                listener.exitComponent(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitComponent" ):
                return visitor.visitComponent(self)
            else:
                return visitor.visitChildren(self)




    def component(self):

        localctx = wxclParser.ComponentContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_component)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 159
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [11]:
                self.state = 147
                self.swiper()
                pass
            elif token in [14]:
                self.state = 148
                self.text()
                pass
            elif token in [15]:
                self.state = 149
                self.image()
                pass
            elif token in [16]:
                self.state = 150
                self.button()
                pass
            elif token in [22]:
                self.state = 151
                self.list_()
                pass
            elif token in [23]:
                self.state = 152
                self.form()
                pass
            elif token in [24]:
                self.state = 153
                self.label()
                pass
            elif token in [25]:
                self.state = 154
                self.radioGroup()
                pass
            elif token in [27]:
                self.state = 155
                self.checkboxGroup()
                pass
            elif token in [28]:
                self.state = 156
                self.input_()
                pass
            elif token in [30]:
                self.state = 157
                self.view()
                pass
            elif token in [31]:
                self.state = 158
                self.navigator()
                pass
            else:
                raise NoViableAltException(self)

            self.state = 166
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 161
                self.match(wxclParser.T__9)
                self.state = 164
                self._errHandler.sync(self)
                token = self._input.LA(1)
                if token in [32]:
                    self.state = 162
                    self.gui()
                    pass
                elif token in [63]:
                    self.state = 163
                    self.match(wxclParser.VariableName)
                    pass
                else:
                    raise NoViableAltException(self)



            self.state = 168
            self.match(wxclParser.T__2)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SwiperContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ablum(self):
            return self.getTypedRuleContext(wxclParser.AblumContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_swiper

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSwiper" ):
                listener.enterSwiper(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSwiper" ):
                listener.exitSwiper(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSwiper" ):
                return visitor.visitSwiper(self)
            else:
                return visitor.visitChildren(self)




    def swiper(self):

        localctx = wxclParser.SwiperContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_swiper)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 170
            self.match(wxclParser.T__10)
            self.state = 171
            self.match(wxclParser.T__11)
            self.state = 173
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==61:
                self.state = 172
                self.ablum()


            self.state = 175
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AblumContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self, i:int=None):
            if i is None:
                return self.getTokens(wxclParser.String)
            else:
                return self.getToken(wxclParser.String, i)

        def getRuleIndex(self):
            return wxclParser.RULE_ablum

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAblum" ):
                listener.enterAblum(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAblum" ):
                listener.exitAblum(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitAblum" ):
                return visitor.visitAblum(self)
            else:
                return visitor.visitChildren(self)




    def ablum(self):

        localctx = wxclParser.AblumContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_ablum)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 177
            self.match(wxclParser.String)
            self.state = 182
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==6:
                self.state = 178
                self.match(wxclParser.T__5)
                self.state = 179
                self.match(wxclParser.String)
                self.state = 184
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TextContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_text

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterText" ):
                listener.enterText(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitText" ):
                listener.exitText(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitText" ):
                return visitor.visitText(self)
            else:
                return visitor.visitChildren(self)




    def text(self):

        localctx = wxclParser.TextContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_text)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 185
            self.match(wxclParser.T__13)
            self.state = 186
            self.match(wxclParser.T__8)
            self.state = 187
            self.match(wxclParser.String)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ImageContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_image

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterImage" ):
                listener.enterImage(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitImage" ):
                listener.exitImage(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitImage" ):
                return visitor.visitImage(self)
            else:
                return visitor.visitChildren(self)




    def image(self):

        localctx = wxclParser.ImageContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_image)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 189
            self.match(wxclParser.T__14)
            self.state = 190
            self.match(wxclParser.T__8)
            self.state = 191
            self.match(wxclParser.String)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ButtonContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def function(self):
            return self.getTypedRuleContext(wxclParser.FunctionContext,0)


        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_button

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterButton" ):
                listener.enterButton(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitButton" ):
                listener.exitButton(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitButton" ):
                return visitor.visitButton(self)
            else:
                return visitor.visitChildren(self)




    def button(self):

        localctx = wxclParser.ButtonContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_button)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 193
            self.match(wxclParser.T__15)
            self.state = 194
            self.match(wxclParser.T__16)
            self.state = 195
            self.function()
            self.state = 196
            self.match(wxclParser.T__17)
            self.state = 197
            self.match(wxclParser.T__8)
            self.state = 198
            self.match(wxclParser.String)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FunctionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def VariableName(self):
            return self.getToken(wxclParser.VariableName, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_function

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFunction" ):
                listener.enterFunction(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFunction" ):
                listener.exitFunction(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFunction" ):
                return visitor.visitFunction(self)
            else:
                return visitor.visitChildren(self)




    def function(self):

        localctx = wxclParser.FunctionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_function)
        try:
            self.state = 205
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [19]:
                self.enterOuterAlt(localctx, 1)
                self.state = 200
                self.match(wxclParser.T__18)
                self.state = 201
                self.match(wxclParser.T__8)
                self.state = 202
                self.match(wxclParser.VariableName)
                pass
            elif token in [20]:
                self.enterOuterAlt(localctx, 2)
                self.state = 203
                self.match(wxclParser.T__19)
                pass
            elif token in [21]:
                self.enterOuterAlt(localctx, 3)
                self.state = 204
                self.match(wxclParser.T__20)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ListContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pageContent(self):
            return self.getTypedRuleContext(wxclParser.PageContentContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterList" ):
                listener.enterList(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitList" ):
                listener.exitList(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitList" ):
                return visitor.visitList(self)
            else:
                return visitor.visitChildren(self)




    def list_(self):

        localctx = wxclParser.ListContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_list)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 207
            self.match(wxclParser.T__21)
            self.state = 208
            self.match(wxclParser.T__11)
            self.state = 209
            self.pageContent()
            self.state = 210
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FormContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def pageContent(self):
            return self.getTypedRuleContext(wxclParser.PageContentContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_form

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterForm" ):
                listener.enterForm(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitForm" ):
                listener.exitForm(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitForm" ):
                return visitor.visitForm(self)
            else:
                return visitor.visitChildren(self)




    def form(self):

        localctx = wxclParser.FormContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_form)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 212
            self.match(wxclParser.T__22)
            self.state = 213
            self.match(wxclParser.T__16)
            self.state = 214
            self.match(wxclParser.String)
            self.state = 215
            self.match(wxclParser.T__17)
            self.state = 216
            self.match(wxclParser.T__11)
            self.state = 217
            self.pageContent()
            self.state = 218
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class LabelContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pageContent(self):
            return self.getTypedRuleContext(wxclParser.PageContentContext,0)


        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_label

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLabel" ):
                listener.enterLabel(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLabel" ):
                listener.exitLabel(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitLabel" ):
                return visitor.visitLabel(self)
            else:
                return visitor.visitChildren(self)




    def label(self):

        localctx = wxclParser.LabelContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_label)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 220
            self.match(wxclParser.T__23)
            self.state = 224
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==17:
                self.state = 221
                self.match(wxclParser.T__16)
                self.state = 222
                self.match(wxclParser.String)
                self.state = 223
                self.match(wxclParser.T__17)


            self.state = 226
            self.match(wxclParser.T__11)
            self.state = 227
            self.pageContent()
            self.state = 228
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class RadioGroupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def radioOption(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.RadioOptionContext)
            else:
                return self.getTypedRuleContext(wxclParser.RadioOptionContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_radioGroup

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRadioGroup" ):
                listener.enterRadioGroup(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRadioGroup" ):
                listener.exitRadioGroup(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRadioGroup" ):
                return visitor.visitRadioGroup(self)
            else:
                return visitor.visitChildren(self)




    def radioGroup(self):

        localctx = wxclParser.RadioGroupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_radioGroup)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 230
            self.match(wxclParser.T__24)
            self.state = 231
            self.match(wxclParser.T__1)
            self.state = 232
            self.match(wxclParser.String)
            self.state = 233
            self.match(wxclParser.T__11)
            self.state = 234
            self.radioOption()
            self.state = 239
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==6:
                self.state = 235
                self.match(wxclParser.T__5)
                self.state = 236
                self.radioOption()
                self.state = 241
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 242
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class RadioOptionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_radioOption

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRadioOption" ):
                listener.enterRadioOption(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRadioOption" ):
                listener.exitRadioOption(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRadioOption" ):
                return visitor.visitRadioOption(self)
            else:
                return visitor.visitChildren(self)




    def radioOption(self):

        localctx = wxclParser.RadioOptionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_radioOption)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 244
            self.match(wxclParser.String)
            self.state = 246
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==26:
                self.state = 245
                self.match(wxclParser.T__25)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CheckboxGroupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def checkboxOption(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.CheckboxOptionContext)
            else:
                return self.getTypedRuleContext(wxclParser.CheckboxOptionContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_checkboxGroup

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCheckboxGroup" ):
                listener.enterCheckboxGroup(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCheckboxGroup" ):
                listener.exitCheckboxGroup(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCheckboxGroup" ):
                return visitor.visitCheckboxGroup(self)
            else:
                return visitor.visitChildren(self)




    def checkboxGroup(self):

        localctx = wxclParser.CheckboxGroupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_checkboxGroup)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 248
            self.match(wxclParser.T__26)
            self.state = 249
            self.match(wxclParser.T__1)
            self.state = 250
            self.match(wxclParser.String)
            self.state = 251
            self.match(wxclParser.T__11)
            self.state = 252
            self.checkboxOption()
            self.state = 257
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==6:
                self.state = 253
                self.match(wxclParser.T__5)
                self.state = 254
                self.checkboxOption()
                self.state = 259
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 260
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CheckboxOptionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_checkboxOption

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCheckboxOption" ):
                listener.enterCheckboxOption(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCheckboxOption" ):
                listener.exitCheckboxOption(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitCheckboxOption" ):
                return visitor.visitCheckboxOption(self)
            else:
                return visitor.visitChildren(self)




    def checkboxOption(self):

        localctx = wxclParser.CheckboxOptionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_checkboxOption)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 262
            self.match(wxclParser.String)
            self.state = 264
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==26:
                self.state = 263
                self.match(wxclParser.T__25)


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InputContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def inputType(self):
            return self.getTypedRuleContext(wxclParser.InputTypeContext,0)


        def String(self, i:int=None):
            if i is None:
                return self.getTokens(wxclParser.String)
            else:
                return self.getToken(wxclParser.String, i)

        def getRuleIndex(self):
            return wxclParser.RULE_input

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInput" ):
                listener.enterInput(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInput" ):
                listener.exitInput(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInput" ):
                return visitor.visitInput(self)
            else:
                return visitor.visitChildren(self)




    def input_(self):

        localctx = wxclParser.InputContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_input)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 266
            self.match(wxclParser.T__27)
            self.state = 267
            self.match(wxclParser.T__16)
            self.state = 268
            self.inputType()
            self.state = 269
            self.match(wxclParser.T__17)
            self.state = 272
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==9:
                self.state = 270
                self.match(wxclParser.T__8)
                self.state = 271
                self.match(wxclParser.String)


            self.state = 274
            self.match(wxclParser.T__1)
            self.state = 275
            self.match(wxclParser.String)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class InputTypeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser


        def getRuleIndex(self):
            return wxclParser.RULE_inputType

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInputType" ):
                listener.enterInputType(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInputType" ):
                listener.exitInputType(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitInputType" ):
                return visitor.visitInputType(self)
            else:
                return visitor.visitChildren(self)




    def inputType(self):

        localctx = wxclParser.InputTypeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_inputType)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 277
            _la = self._input.LA(1)
            if not(_la==14 or _la==29):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ViewContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pageContent(self):
            return self.getTypedRuleContext(wxclParser.PageContentContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_view

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterView" ):
                listener.enterView(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitView" ):
                listener.exitView(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitView" ):
                return visitor.visitView(self)
            else:
                return visitor.visitChildren(self)




    def view(self):

        localctx = wxclParser.ViewContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_view)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 279
            self.match(wxclParser.T__29)
            self.state = 280
            self.match(wxclParser.T__11)
            self.state = 281
            self.pageContent()
            self.state = 282
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NavigatorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def VariableName(self):
            return self.getToken(wxclParser.VariableName, 0)

        def pageContent(self):
            return self.getTypedRuleContext(wxclParser.PageContentContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_navigator

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNavigator" ):
                listener.enterNavigator(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNavigator" ):
                listener.exitNavigator(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitNavigator" ):
                return visitor.visitNavigator(self)
            else:
                return visitor.visitChildren(self)




    def navigator(self):

        localctx = wxclParser.NavigatorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_navigator)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 284
            self.match(wxclParser.T__30)
            self.state = 285
            self.match(wxclParser.T__16)
            self.state = 286
            self.match(wxclParser.VariableName)
            self.state = 287
            self.match(wxclParser.T__17)
            self.state = 288
            self.match(wxclParser.T__11)
            self.state = 289
            self.pageContent()
            self.state = 290
            self.match(wxclParser.T__12)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class GuiContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def style(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.StyleContext)
            else:
                return self.getTypedRuleContext(wxclParser.StyleContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_gui

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterGui" ):
                listener.enterGui(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitGui" ):
                listener.exitGui(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitGui" ):
                return visitor.visitGui(self)
            else:
                return visitor.visitChildren(self)




    def gui(self):

        localctx = wxclParser.GuiContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_gui)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 292
            self.match(wxclParser.T__31)
            self.state = 293
            self.style()
            self.state = 298
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==6:
                self.state = 294
                self.match(wxclParser.T__5)
                self.state = 295
                self.style()
                self.state = 300
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 301
            self.match(wxclParser.T__31)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class StyleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def color(self):
            return self.getTypedRuleContext(wxclParser.ColorContext,0)


        def width(self):
            return self.getTypedRuleContext(wxclParser.WidthContext,0)


        def height(self):
            return self.getTypedRuleContext(wxclParser.HeightContext,0)


        def border(self):
            return self.getTypedRuleContext(wxclParser.BorderContext,0)


        def position(self):
            return self.getTypedRuleContext(wxclParser.PositionContext,0)


        def font(self):
            return self.getTypedRuleContext(wxclParser.FontContext,0)


        def textAlign(self):
            return self.getTypedRuleContext(wxclParser.TextAlignContext,0)


        def background(self):
            return self.getTypedRuleContext(wxclParser.BackgroundContext,0)


        def spacing(self):
            return self.getTypedRuleContext(wxclParser.SpacingContext,0)


        def borderRadius(self):
            return self.getTypedRuleContext(wxclParser.BorderRadiusContext,0)


        def padding(self):
            return self.getTypedRuleContext(wxclParser.PaddingContext,0)


        def list_col(self):
            return self.getTypedRuleContext(wxclParser.List_colContext,0)


        def list_rowHeight(self):
            return self.getTypedRuleContext(wxclParser.List_rowHeightContext,0)


        def swiper_interval(self):
            return self.getTypedRuleContext(wxclParser.Swiper_intervalContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_style

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStyle" ):
                listener.enterStyle(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStyle" ):
                listener.exitStyle(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitStyle" ):
                return visitor.visitStyle(self)
            else:
                return visitor.visitChildren(self)




    def style(self):

        localctx = wxclParser.StyleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 54, self.RULE_style)
        try:
            self.state = 317
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [33]:
                self.enterOuterAlt(localctx, 1)
                self.state = 303
                self.color()
                pass
            elif token in [34]:
                self.enterOuterAlt(localctx, 2)
                self.state = 304
                self.width()
                pass
            elif token in [35]:
                self.enterOuterAlt(localctx, 3)
                self.state = 305
                self.height()
                pass
            elif token in [36]:
                self.enterOuterAlt(localctx, 4)
                self.state = 306
                self.border()
                pass
            elif token in [41]:
                self.enterOuterAlt(localctx, 5)
                self.state = 307
                self.position()
                pass
            elif token in [42]:
                self.enterOuterAlt(localctx, 6)
                self.state = 308
                self.font()
                pass
            elif token in [43]:
                self.enterOuterAlt(localctx, 7)
                self.state = 309
                self.textAlign()
                pass
            elif token in [44]:
                self.enterOuterAlt(localctx, 8)
                self.state = 310
                self.background()
                pass
            elif token in [45]:
                self.enterOuterAlt(localctx, 9)
                self.state = 311
                self.spacing()
                pass
            elif token in [46]:
                self.enterOuterAlt(localctx, 10)
                self.state = 312
                self.borderRadius()
                pass
            elif token in [47]:
                self.enterOuterAlt(localctx, 11)
                self.state = 313
                self.padding()
                pass
            elif token in [48]:
                self.enterOuterAlt(localctx, 12)
                self.state = 314
                self.list_col()
                pass
            elif token in [49]:
                self.enterOuterAlt(localctx, 13)
                self.state = 315
                self.list_rowHeight()
                pass
            elif token in [50]:
                self.enterOuterAlt(localctx, 14)
                self.state = 316
                self.swiper_interval()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ColorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ColorValue(self):
            return self.getToken(wxclParser.ColorValue, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_color

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterColor" ):
                listener.enterColor(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitColor" ):
                listener.exitColor(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitColor" ):
                return visitor.visitColor(self)
            else:
                return visitor.visitChildren(self)




    def color(self):

        localctx = wxclParser.ColorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 56, self.RULE_color)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 319
            self.match(wxclParser.T__32)
            self.state = 320
            self.match(wxclParser.T__1)
            self.state = 321
            self.match(wxclParser.ColorValue)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class WidthContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self):
            return self.getTypedRuleContext(wxclParser.RpxValueContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_width

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWidth" ):
                listener.enterWidth(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWidth" ):
                listener.exitWidth(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitWidth" ):
                return visitor.visitWidth(self)
            else:
                return visitor.visitChildren(self)




    def width(self):

        localctx = wxclParser.WidthContext(self, self._ctx, self.state)
        self.enterRule(localctx, 58, self.RULE_width)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 323
            self.match(wxclParser.T__33)
            self.state = 324
            self.match(wxclParser.T__1)
            self.state = 325
            self.rpxValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class HeightContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self):
            return self.getTypedRuleContext(wxclParser.RpxValueContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_height

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterHeight" ):
                listener.enterHeight(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitHeight" ):
                listener.exitHeight(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitHeight" ):
                return visitor.visitHeight(self)
            else:
                return visitor.visitChildren(self)




    def height(self):

        localctx = wxclParser.HeightContext(self, self._ctx, self.state)
        self.enterRule(localctx, 60, self.RULE_height)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 327
            self.match(wxclParser.T__34)
            self.state = 328
            self.match(wxclParser.T__1)
            self.state = 329
            self.rpxValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BorderContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def borderWidth(self):
            return self.getTypedRuleContext(wxclParser.BorderWidthContext,0)


        def BorderStyle(self):
            return self.getToken(wxclParser.BorderStyle, 0)

        def borderColor(self):
            return self.getTypedRuleContext(wxclParser.BorderColorContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_border

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBorder" ):
                listener.enterBorder(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBorder" ):
                listener.exitBorder(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBorder" ):
                return visitor.visitBorder(self)
            else:
                return visitor.visitChildren(self)




    def border(self):

        localctx = wxclParser.BorderContext(self, self._ctx, self.state)
        self.enterRule(localctx, 62, self.RULE_border)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 331
            self.match(wxclParser.T__35)
            self.state = 332
            self.match(wxclParser.T__36)
            self.state = 333
            self.borderWidth()
            self.state = 334
            self.match(wxclParser.T__5)
            self.state = 335
            self.match(wxclParser.BorderStyle)
            self.state = 336
            self.match(wxclParser.T__5)
            self.state = 337
            self.borderColor()
            self.state = 338
            self.match(wxclParser.T__37)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BorderWidthContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self):
            return self.getTypedRuleContext(wxclParser.RpxValueContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_borderWidth

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBorderWidth" ):
                listener.enterBorderWidth(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBorderWidth" ):
                listener.exitBorderWidth(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBorderWidth" ):
                return visitor.visitBorderWidth(self)
            else:
                return visitor.visitChildren(self)




    def borderWidth(self):

        localctx = wxclParser.BorderWidthContext(self, self._ctx, self.state)
        self.enterRule(localctx, 64, self.RULE_borderWidth)
        try:
            self.state = 342
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [60]:
                self.enterOuterAlt(localctx, 1)
                self.state = 340
                self.rpxValue()
                pass
            elif token in [39]:
                self.enterOuterAlt(localctx, 2)
                self.state = 341
                self.match(wxclParser.T__38)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BorderColorContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ColorValue(self):
            return self.getToken(wxclParser.ColorValue, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_borderColor

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBorderColor" ):
                listener.enterBorderColor(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBorderColor" ):
                listener.exitBorderColor(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBorderColor" ):
                return visitor.visitBorderColor(self)
            else:
                return visitor.visitChildren(self)




    def borderColor(self):

        localctx = wxclParser.BorderColorContext(self, self._ctx, self.state)
        self.enterRule(localctx, 66, self.RULE_borderColor)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 344
            _la = self._input.LA(1)
            if not(_la==40 or _la==56):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PositionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HorizontalValue(self):
            return self.getToken(wxclParser.HorizontalValue, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_position

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPosition" ):
                listener.enterPosition(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPosition" ):
                listener.exitPosition(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPosition" ):
                return visitor.visitPosition(self)
            else:
                return visitor.visitChildren(self)




    def position(self):

        localctx = wxclParser.PositionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 68, self.RULE_position)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 346
            self.match(wxclParser.T__40)
            self.state = 347
            self.match(wxclParser.T__1)
            self.state = 348
            self.match(wxclParser.HorizontalValue)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FontContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FontWeight(self):
            return self.getToken(wxclParser.FontWeight, 0)

        def fontSize(self):
            return self.getTypedRuleContext(wxclParser.FontSizeContext,0)


        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_font

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFont" ):
                listener.enterFont(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFont" ):
                listener.exitFont(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFont" ):
                return visitor.visitFont(self)
            else:
                return visitor.visitChildren(self)




    def font(self):

        localctx = wxclParser.FontContext(self, self._ctx, self.state)
        self.enterRule(localctx, 70, self.RULE_font)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 350
            self.match(wxclParser.T__41)
            self.state = 351
            self.match(wxclParser.T__36)
            self.state = 352
            self.match(wxclParser.FontWeight)
            self.state = 353
            self.match(wxclParser.T__5)
            self.state = 354
            self.fontSize()
            self.state = 355
            self.match(wxclParser.T__5)
            self.state = 356
            self.match(wxclParser.String)
            self.state = 357
            self.match(wxclParser.T__37)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FontSizeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self):
            return self.getTypedRuleContext(wxclParser.RpxValueContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_fontSize

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFontSize" ):
                listener.enterFontSize(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFontSize" ):
                listener.exitFontSize(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitFontSize" ):
                return visitor.visitFontSize(self)
            else:
                return visitor.visitChildren(self)




    def fontSize(self):

        localctx = wxclParser.FontSizeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 72, self.RULE_fontSize)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 359
            self.rpxValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TextAlignContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HorizontalValue(self):
            return self.getToken(wxclParser.HorizontalValue, 0)

        def VerticalValue(self):
            return self.getToken(wxclParser.VerticalValue, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_textAlign

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTextAlign" ):
                listener.enterTextAlign(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTextAlign" ):
                listener.exitTextAlign(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitTextAlign" ):
                return visitor.visitTextAlign(self)
            else:
                return visitor.visitChildren(self)




    def textAlign(self):

        localctx = wxclParser.TextAlignContext(self, self._ctx, self.state)
        self.enterRule(localctx, 74, self.RULE_textAlign)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 361
            self.match(wxclParser.T__42)
            self.state = 362
            self.match(wxclParser.T__1)
            self.state = 363
            self.match(wxclParser.HorizontalValue)
            self.state = 364
            self.match(wxclParser.T__8)
            self.state = 365
            self.match(wxclParser.VerticalValue)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BackgroundContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ColorValue(self):
            return self.getToken(wxclParser.ColorValue, 0)

        def String(self):
            return self.getToken(wxclParser.String, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_background

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBackground" ):
                listener.enterBackground(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBackground" ):
                listener.exitBackground(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBackground" ):
                return visitor.visitBackground(self)
            else:
                return visitor.visitChildren(self)




    def background(self):

        localctx = wxclParser.BackgroundContext(self, self._ctx, self.state)
        self.enterRule(localctx, 76, self.RULE_background)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 367
            self.match(wxclParser.T__43)
            self.state = 368
            self.match(wxclParser.T__36)
            self.state = 369
            self.match(wxclParser.ColorValue)
            self.state = 372
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==6:
                self.state = 370
                self.match(wxclParser.T__5)
                self.state = 371
                self.match(wxclParser.String)


            self.state = 374
            self.match(wxclParser.T__37)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SpacingContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(wxclParser.RpxValueContext)
            else:
                return self.getTypedRuleContext(wxclParser.RpxValueContext,i)


        def getRuleIndex(self):
            return wxclParser.RULE_spacing

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSpacing" ):
                listener.enterSpacing(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSpacing" ):
                listener.exitSpacing(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSpacing" ):
                return visitor.visitSpacing(self)
            else:
                return visitor.visitChildren(self)




    def spacing(self):

        localctx = wxclParser.SpacingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 78, self.RULE_spacing)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 376
            self.match(wxclParser.T__44)
            self.state = 377
            self.match(wxclParser.T__36)
            self.state = 378
            self.rpxValue()
            self.state = 379
            self.match(wxclParser.T__5)
            self.state = 380
            self.rpxValue()
            self.state = 381
            self.match(wxclParser.T__37)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class BorderRadiusContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self):
            return self.getTypedRuleContext(wxclParser.RpxValueContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_borderRadius

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBorderRadius" ):
                listener.enterBorderRadius(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBorderRadius" ):
                listener.exitBorderRadius(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitBorderRadius" ):
                return visitor.visitBorderRadius(self)
            else:
                return visitor.visitChildren(self)




    def borderRadius(self):

        localctx = wxclParser.BorderRadiusContext(self, self._ctx, self.state)
        self.enterRule(localctx, 80, self.RULE_borderRadius)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 383
            self.match(wxclParser.T__45)
            self.state = 384
            self.match(wxclParser.T__1)
            self.state = 385
            self.rpxValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class RpxValueContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Number(self):
            return self.getToken(wxclParser.Number, 0)

        def Unit(self):
            return self.getToken(wxclParser.Unit, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_rpxValue

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRpxValue" ):
                listener.enterRpxValue(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRpxValue" ):
                listener.exitRpxValue(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitRpxValue" ):
                return visitor.visitRpxValue(self)
            else:
                return visitor.visitChildren(self)




    def rpxValue(self):

        localctx = wxclParser.RpxValueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 82, self.RULE_rpxValue)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 387
            self.match(wxclParser.Number)
            self.state = 388
            self.match(wxclParser.Unit)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PaddingContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self):
            return self.getTypedRuleContext(wxclParser.RpxValueContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_padding

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPadding" ):
                listener.enterPadding(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPadding" ):
                listener.exitPadding(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitPadding" ):
                return visitor.visitPadding(self)
            else:
                return visitor.visitChildren(self)




    def padding(self):

        localctx = wxclParser.PaddingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 84, self.RULE_padding)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 390
            self.match(wxclParser.T__46)
            self.state = 391
            self.match(wxclParser.T__1)
            self.state = 392
            self.rpxValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class List_colContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Number(self):
            return self.getToken(wxclParser.Number, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_list_col

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterList_col" ):
                listener.enterList_col(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitList_col" ):
                listener.exitList_col(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitList_col" ):
                return visitor.visitList_col(self)
            else:
                return visitor.visitChildren(self)




    def list_col(self):

        localctx = wxclParser.List_colContext(self, self._ctx, self.state)
        self.enterRule(localctx, 86, self.RULE_list_col)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 394
            self.match(wxclParser.T__47)
            self.state = 395
            self.match(wxclParser.T__1)
            self.state = 396
            self.match(wxclParser.Number)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class List_rowHeightContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def rpxValue(self):
            return self.getTypedRuleContext(wxclParser.RpxValueContext,0)


        def getRuleIndex(self):
            return wxclParser.RULE_list_rowHeight

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterList_rowHeight" ):
                listener.enterList_rowHeight(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitList_rowHeight" ):
                listener.exitList_rowHeight(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitList_rowHeight" ):
                return visitor.visitList_rowHeight(self)
            else:
                return visitor.visitChildren(self)




    def list_rowHeight(self):

        localctx = wxclParser.List_rowHeightContext(self, self._ctx, self.state)
        self.enterRule(localctx, 88, self.RULE_list_rowHeight)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 398
            self.match(wxclParser.T__48)
            self.state = 399
            self.match(wxclParser.T__1)
            self.state = 400
            self.rpxValue()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Swiper_intervalContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Number(self):
            return self.getToken(wxclParser.Number, 0)

        def getRuleIndex(self):
            return wxclParser.RULE_swiper_interval

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSwiper_interval" ):
                listener.enterSwiper_interval(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSwiper_interval" ):
                listener.exitSwiper_interval(self)

        def accept(self, visitor:ParseTreeVisitor):
            if hasattr( visitor, "visitSwiper_interval" ):
                return visitor.visitSwiper_interval(self)
            else:
                return visitor.visitChildren(self)




    def swiper_interval(self):

        localctx = wxclParser.Swiper_intervalContext(self, self._ctx, self.state)
        self.enterRule(localctx, 90, self.RULE_swiper_interval)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 402
            self.match(wxclParser.T__49)
            self.state = 403
            self.match(wxclParser.T__1)
            self.state = 404
            self.match(wxclParser.Number)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx





